Package: openssl
Type: Package
Title: Toolkit for Encryption, Signatures and Certificates Based on
        OpenSSL
Version: 1.0.1
Authors@R: c(person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroen@berkeley.edu",
    comment = c(ORCID = "0000-0002-4035-0289")),
    person("Oliver", "Keyes", role = "ctb"))
Description: Bindings to OpenSSL libssl and libcrypto, plus custom SSH pubkey parsers.
    Supports RSA, DSA and EC curves P-256, P-384 and P-521. Cryptographic signatures
    can either be created and verified manually or via x509 certificates. AES can be
    used in cbc, ctr or gcm mode for symmetric encryption; RSA for asymmetric (public
    key) encryption or EC for Diffie Hellman. High-level envelope functions combine
    RSA and AES for encrypting arbitrary sized data. Other utilities include key
    generators, hash functions (md5, sha1, sha256, etc), base64 encoder, a secure
    random number generator, and 'bignum' math methods for manually performing
    crypto calculations on large multibyte integers.
License: MIT + file LICENSE
URL: https://github.com/jeroen/openssl#readme
BugReports: https://github.com/jeroen/openssl/issues
SystemRequirements: OpenSSL >= 1.0.1
VignetteBuilder: knitr
Suggests: testthat, digest, knitr, rmarkdown, jsonlite, jose
RoxygenNote: 6.0.1.9000
NeedsCompilation: yes
Packaged: 2018-03-03 10:51:56 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>),
  Oliver Keyes [ctb]
Maintainer: Jeroen Ooms <jeroen@berkeley.edu>
Repository: CRAN
Date/Publication: 2018-03-03 14:03:23 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2018-03-09 13:20:20 UTC; windows
Archs: x64
